import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.border.*;
import javax.swing.event.*;

/*
 * FinchDisplay class
 * 
 * <P>
 * Create a frame that contains components for displaying Finch sensor
 * values and 
 * 
 * <P>
 * FinchDisplay
 * <OL>
 * <LI>
 * </OL>
 * 
 */

public class FinchDisplay extends JFrame {

	// References to the text labels that will display sensor values
	private JLabel lightLeft;
	private JLabel lightRight;
	private JLabel accelX;
	private JLabel accelY;
	private JLabel accelZ;
	private JLabel obstacleLeft;
	private JLabel obstacleRight;
	private JLabel temperature;
	
	// RGB values
	private int LED[];
	
	// Set to true if the window is open
	private boolean openFlag;

	
	/**
	 * Constructor of the Finch display frame.  Creates all of the
	 * frame contents.
	 *  
	 */
	
	public FinchDisplay()
	{	
		// Initialize the RGB LED array
		this.LED = new int[3];
		
		// Indicate that the window is open (or will soon be)
		this.openFlag = true;
		
		// Set up a grid that will have 1 column (and an arbitrary number of rows)
		this.setLayout(new GridLayout(0, 1, 10, 10));
		
		/////////////////////////////////////////////////////////
		// Light panel
		JPanel p1 = new JPanel(new GridLayout(0, 2, 10, 10));
		// Border for this pair of values
		p1.setBorder(new TitledBorder("Light Sensors"));

		// Value to be displayed.  Note, we save a 'handle' to this object
		//   so we can update it later.
		lightLeft = new JLabel("none");
		p1.add(lightLeft);
		
		// Value to be displayed
		lightRight = new JLabel("none");
		p1.add(lightRight);
		
		// Add this panel to the frame
		this.add(p1);
		
		/////////////////////////////////////////////////
		// Accelerometer panel
		JPanel Paccel = new JPanel(new GridLayout(0, 3, 10, 10));
		// Border for this pair of values
		Paccel.setBorder(new TitledBorder("Accelerometers"));
		
		// TODO: create the JLabels for the 3 accelerometer values
		
		
		/////////////////////////////////////////////////
		// Obstacle panel
		
		// TODO: create a JPanel and two JLabels for the obstacle sensor values
		
		
		/////////////////////////////////////////////////
		// Temperature panel
		
		// TODO: create a JPanel and the JLabel for the temperature panel
		
		
		/////////////////////////
		// Sliders for specifying RGB
		JPanel Pslider = new JPanel(new GridLayout(0, 1, 10, 10));
		
		// Slider for Red LED
		// The parameters for this constructor are: min value, max value, and default value
		final JSlider slider1 = new JSlider(0, 255, 0);
		
		// Set up a listener: stateChanged event is called when 
		//  the slider is moved.
		slider1.addChangeListener(new ChangeListener(){
			public void stateChanged(ChangeEvent e){
				LED[0] = slider1.getValue();
			}
		});
		Pslider.add(slider1);
		
		// Slider for Green LED
		final JSlider slider2 = new JSlider(0, 255, 0);
		
		// Set up a listener: stateChanged event is called when 
		//  the slider is moved.
		slider2.addChangeListener(new ChangeListener(){
			public void stateChanged(ChangeEvent e){
				LED[1] = slider2.getValue();
			}
		});
		Pslider.add(slider2);
		
		// Slider for Blue LED
		final JSlider slider3 = new JSlider(0, 255, 0);
		
		// Set up a listener: stateChanged event is called when 
		//  the slider is moved.
		slider3.addChangeListener(new ChangeListener(){
			public void stateChanged(ChangeEvent e){
				LED[2] = slider3.getValue();
			}
		});
		
		Pslider.add(slider3);
		
		// Finish off Slider panel configuration
		
		Pslider.setBorder(new TitledBorder("RGB"));
		this.add(Pslider);
		
		//////////////////////////
		// Detect when the window is closed
		this.addWindowListener(new WindowListener(){
			public void windowOpened(WindowEvent event) {
			}
			public void windowDeactivated(WindowEvent event) {
			}
			public void windowActivated(WindowEvent event) {
			}
			public void windowDeiconified(WindowEvent event) {
			}
			public void windowIconified(WindowEvent event) {
			}
			public void windowClosing(WindowEvent event) {
				closeFinch();
				System.out.println("closing...");
			}
			public void windowClosed(WindowEvent event) {
			};
		});
	}
	
	/**
	 *  Method to be called in response to window being closed.
	 *   
	 *  <P>
	 *  Postconditions:
	 * <OL> 
	 * <LI>  The openFlag is set to false to indicate that the driver
	 * program should shut down
	 * </OL>
	 */
	private void closeFinch()
	{
		this.openFlag = false;
	}
	
	/**
	 * 
	 * @return True if the window is currently open; false otherwise
	 */
	
	public boolean getOpenFlag()
	{
		return(this.openFlag);
	}
	
	/**
	 * Change the light sensor values that are displayed
	 * 
	 * @param left	The value of the left light sensor
	 * @param right The value of the right light sensor
	 * 
	 */
	public void setLight(Integer left, Integer right)
	{
		lightLeft.setText(left.toString());
		lightRight.setText(right.toString());
	}
	
	// TODO: add mutator methods for setting accelerometer, obstacle, and temperature
	//  values
	
	
	/**
	 * 
	 * 
	 * @return The RGB array that contains the current desired values of the LED.
	 */
	public int[] getLED(){
		return(LED);
	}
	
}
